package uranodai.oscemote
{
	import flash.events.Event;
	import flash.events.EventDispatcher;
	import flash.events.IOErrorEvent;
	
	import it.h_umus.osc.OSCArgument;
	import it.h_umus.osc.OSCConnection;
	import it.h_umus.osc.OSCConnectionEvent;
	import it.h_umus.osc.OSCMessage;
	import it.h_umus.osc.OSCPacket;
	
	import uranodai.oscemote.event.OSCemoteAccelerationEvent;
	import uranodai.oscemote.event.OSCemoteAccelerometerEvent;
	import uranodai.oscemote.event.OSCemoteButtonEvent;
	import uranodai.oscemote.event.OSCemoteCustomEvent;
	import uranodai.oscemote.event.OSCemoteSegmentEvent;
	import uranodai.oscemote.event.OSCemoteSliderEvent;
	import uranodai.oscemote.event.OSCemoteStartUpEvent;
	import uranodai.oscemote.event.OSCemoteSwitchEvent;
	import uranodai.oscemote.event.OSCemoteTouchEvent;		
	
	public class IPhoneas extends EventDispatcher
	{
		private var osc:OSCConnection;
		private var host:String;
		private var port:int;
		
		public function IPhoneas(host:String="localhost", port:int=3000)
		{
			this.host = host;
			this.port = port;
			
			osc = new OSCConnection();
			osc.addEventListener(Event.CONNECT, trace);
			osc.addEventListener(Event.CLOSE, trace);
			osc.addEventListener(IOErrorEvent.IO_ERROR, trace);
			osc.addEventListener(OSCConnectionEvent.OSC_PACKET_IN, oscPacketInHandler);
		}
		
		public function get connection():OSCConnection
		{
			return osc;
		}
		
		public function connect():void
		{
			osc.connect(host, port);
		}
		
		public function close():void
		{
			osc.close();
		}
		
		private function oscPacketInHandler(e:OSCConnectionEvent):void
		{
			var packet:OSCPacket = e.data as OSCPacket;
//			trace('oscPacketInHandler ---------');
//			for each (var msg:OSCMessage in packet.messages) {
//				trace(msg.name);
//				for each (var args:OSCArgument in msg.arguments) {
//					trace('   ', args.type, '->', args.value);
//				}
//			}
			
			var msg0:OSCMessage = packet.messages[0];
			var names:Array = msg0.name.split('/');
//			trace(names);
			var ival:int;
			var fval:Number;
			var bval:Boolean;
			switch (names[1]) {
				case 'hello':
					var deviceID:String = String(OSCArgument(msg0.arguments[0]).value);
					dispatchEvent(new OSCemoteStartUpEvent(OSCemoteStartUpEvent.HELLO, deviceID));
				case 'button':
					ival = int(OSCArgument(msg0.arguments[0]).value);
					var btnEv:OSCemoteButtonEvent = new OSCemoteButtonEvent(ival ? OSCemoteButtonEvent.BUTTON_DOWN : OSCemoteButtonEvent.BUTTON_UP, names[2]);
					this.dispatchEvent(btnEv);
					break;
				case 'slider':
					fval = Number(OSCArgument(msg0.arguments[0]).value);
					var sldEv:OSCemoteSliderEvent = new OSCemoteSliderEvent(OSCemoteSliderEvent.SLIDER_CHANGE, parseInt(names[2]), fval);
					this.dispatchEvent(sldEv);
					break;
				case 'segmented':
					ival = int(OSCArgument(msg0.arguments[0]).value);
					var segEv:OSCemoteSegmentEvent = new OSCemoteSegmentEvent(OSCemoteSegmentEvent.SEGMENT_CHANGE, ival);
					this.dispatchEvent(segEv);
					break;
				case 'switch':
					bval = Boolean(OSCArgument(msg0.arguments[0]).value);
					var swtEv:OSCemoteSwitchEvent = new OSCemoteSwitchEvent(OSCemoteSwitchEvent.STATE_CHANGE, parseInt(names[2]), bval);
					this.dispatchEvent(swtEv);
					break;
				case 'tuio':
					this.dispatchEvent(new OSCemoteTouchEvent(OSCemoteTouchEvent.TOUCH, packet));
					break;
				case 'accelerometer':
					ival = int(OSCArgument(msg0.arguments[0]).value);
					dispatchEvent(new OSCemoteAccelerometerEvent(ival ? OSCemoteAccelerometerEvent.ACCELEROMETER_ON : OSCemoteAccelerometerEvent.ACCELEROMETER_OFF));
					break;
				case 'acceleration':
					var x:Number = Number(OSCArgument(msg0.arguments[0]).value);
					var y:Number = Number(OSCArgument(msg0.arguments[1]).value);
					var z:Number = Number(OSCArgument(msg0.arguments[2]).value);
					var accEv:OSCemoteAccelerationEvent = new OSCemoteAccelerationEvent(OSCemoteAccelerationEvent.ACCELERATION_CHANGE, x, y, z);
					this.dispatchEvent(accEv);
					break;
				default:
					var cEv:OSCemoteCustomEvent = new OSCemoteCustomEvent(msg0.name, packet);
					this.dispatchEvent(cEv);
					break;
			}
		}
	}
}